==> beast-privilege-api-RD1007021-20240229.093509-2-sources.jar: com/thebeastshop/privilege/dto/FrontLimitProductDTO.java <==
package com.thebeastshop.privilege.dto;

import java.io.Serializable;
import java.util.Date;

public class FrontLimitProductDTO implements Serializable {
    private String orderCode;//订单CODE
    private Integer memberId;//会员ID
    private String memberCode;//会员CODE
    private String memberName;//会员昵称
    private String prodCode; //商品CODE
    private Integer num;  //购买数量
    private String channelCode; //渠道CODE
    private Integer spvId; //SPVID
    private Integer accessWay; //适用平台

    public String getOrderCode() {
        return orderCode;
    }

    public void setOrderCode(String orderCode) {
        this.orderCode = orderCode;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Integer getMemberId() {
        return memberId;
    }

    public void setMemberId(Integer memberId) {
        this.memberId = memberId;
    }

    public String getMemberName() {
        return memberName;
    }

    public void setMemberName(String memberName) {
        this.memberName = memberName;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Integer getSpvId() {
        return spvId;
    }

    public void setSpvId(Integer spvId) {
        this.spvId = spvId;
    }

    public Integer getAccessWay() {
        return accessWay;
    }

    public void setAccessWay(Integer accessWay) {
        this.accessWay = accessWay;
    }
}

==> beast-privilege-api-RD1007021-20240311.072112-11-sources.jar: com/thebeastshop/privilege/dto/FrontLimitProductDTO.java <==
package com.thebeastshop.privilege.dto;

import java.io.Serializable;

public class FrontLimitProductDTO implements Serializable {
    private Integer limitProdId; //规则ID
    private String orderCode;//订单CODE
    private Integer memberId;//会员ID
    private String memberCode;//会员CODE
    private String memberName;//会员昵称
    private String prodCode; //商品CODE
    private Integer num;  //购买数量
    private String channelCode; //渠道CODE
    private Integer spvId; //SPVID
    private Integer accessWay; //适用平台

    public String getOrderCode() {
        return orderCode;
    }

    public void setOrderCode(String orderCode) {
        this.orderCode = orderCode;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Integer getMemberId() {
        return memberId;
    }

    public void setMemberId(Integer memberId) {
        this.memberId = memberId;
    }

    public String getMemberName() {
        return memberName;
    }

    public void setMemberName(String memberName) {
        this.memberName = memberName;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Integer getSpvId() {
        return spvId;
    }

    public void setSpvId(Integer spvId) {
        this.spvId = spvId;
    }

    public Integer getAccessWay() {
        return accessWay;
    }

    public void setAccessWay(Integer accessWay) {
        this.accessWay = accessWay;
    }

    public Integer getLimitProdId() {
        return limitProdId;
    }

    public void setLimitProdId(Integer limitProdId) {
        this.limitProdId = limitProdId;
    }
}
